using AutoMapper;
using Microsoft.AspNetCore.Cors;
using Microsoft.AspNetCore.Mvc;
using skydiveLogs_api.DataContract;
using skydiveLogs_api.Domain;
using skydiveLogs_api.DomainBusiness.Interfaces;
using System.Collections.Generic;

namespace skydiveLogs_api.Controllers
{
    public class GearController : Base
    {
        #region Public Constructors

        public GearController(IGearService gearService,
                              IMapper mapper)
        {
            _gearService = gearService;
            _mapper = mapper;
        }

        #endregion Public Constructors

        #region Public Methods

        // DELETE: api/ApiWithActions/5
        [HttpDelete("{id}")]
        [EnableCors]
        public void Delete(int id)
        {
            _gearService.DeleteGearById(id);
        }

        // GET: api/Gear
        [HttpGet]
        [EnableCors]
        public IEnumerable<GearResp> Get()
        {
            //var result = _gearService.GetAllGears(ConnectedUser);
            var result = _gearService.GetAllGears();
            return _mapper.Map<IEnumerable<GearResp>>(result);
        }

        // GET: api/Gear/5
        [HttpGet("{id}")]
        [EnableCors]
        public GearResp Get(int id)
        {
            var result = _gearService.GetGearById(id);
            return _mapper.Map<GearResp>(result);
        }

        // POST: api/Gear
        [HttpPost]
        [EnableCors]
        public void Post([FromBody] GearReq value)
        {
            _gearService.AddNewGear(_mapper.Map<Gear>(value));
        }

        // PUT: api/Gear/5
        [HttpPut("{id}")]
        [EnableCors]
        public void Put(int id, [FromBody] GearReq value)
        {
            _gearService.UpdateGear(id, _mapper.Map<Gear>(value));
        }

        #endregion Public Methods

        #region Private Fields

        private readonly IGearService _gearService;

        private readonly IMapper _mapper;

        #endregion Private Fields
    }
}